package Egg::Release::DBIC;
#
# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
#
# $Id: DBIC.pm 259 2008-02-15 13:59:27Z lushe $
#
use strict;
use warnings;

our $VERSION = '0.02';

1;

__END__

=head1 NAME

Egg::Release::DBIC - Package kit to use DBIx::Class.

=head1 DESCRIPTION

=over 4

=item * Egg::Model::DBIC

Model to use L<DBIx::Class>.

=item * Egg::Helper::Model::DBIC

Helper to generate Schema of data base.

=item * Egg::Plugin::DBIC

Plugin to be able to treat L<Egg::Model::DBIC> conveniently.

=back

=head1 SEE ALSO

L<Egg::Release>,
L<Egg::Model::DBIC>,
L<Egg::Helper::Model::DBIC>,
L<Egg::Plugin::DBIC>,

=head1 AUTHOR

Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2008 Bee Flag, Corp. E<lt>L<http://egg.bomcity.com/>E<gt>, All Rights Reserved.

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself, either Perl version 5.8.6 or,
at your option, any later version of Perl 5 you may have available.

=cut

